# color definitions
foreground      = 'white'
background      = 'black'
fieldbackground = 'grey30'
focusbackground = 'grey'
insertbackground= 'white'

selected        = 'green2'

readonly        = 'grey10'
disabled        = 'grey40'

entry_grey      = 'grey45'
entry_white     = 'grey92'
entry_disabled      = 'black'

tab             = 'grey'

font            = 'TkFixedFont'
# ~ font            = 'Courier 10 bold'
